@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2016 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -60,6 +60,8 @@ class CConfigurationExportBuilder {
 	public function buildTemplates(array $templates) {
 		$this->data['templates'] = [];
 
+		CArrayHelper::sort($templates, ['host']);
+
 		foreach ($templates as $template) {
 			$this->data['templates'][] = [
 				'template' => $template['host'],
@@ -69,13 +71,12 @@ class CConfigurationExportBuilder {
 				'applications' => $this->formatApplications($template['applications']),
 				'items' => $this->formatItems($template['items']),
 				'discovery_rules' => $this->formatDiscoveryRules($template['discoveryRules']),
+				'httptests' => $this->formatHttpTests($template['httptests']),
 				'macros' => $this->formatMacros($template['macros']),
 				'templates' => $this->formatTemplateLinkage($template['parentTemplates']),
 				'screens' => $this->formatScreens($template['screens'])
 			];
 		}
-
-		order_result($this->data['templates'], 'template');
 	}
 
 	/**
@@ -86,6 +87,8 @@ class CConfigurationExportBuilder {
 	public function buildHosts(array $hosts) {
 		$this->data['hosts'] = [];
 
+		CArrayHelper::sort($hosts, ['host']);
+
 		foreach ($hosts as $host) {
 			$host = $this->createInterfaceReferences($host);
 
@@ -111,12 +114,11 @@ class CConfigurationExportBuilder {
 				'applications' => $this->formatApplications($host['applications']),
 				'items' => $this->formatItems($host['items']),
 				'discovery_rules' => $this->formatDiscoveryRules($host['discoveryRules']),
+				'httptests' => $this->formatHttpTests($host['httptests']),
 				'macros' => $this->formatMacros($host['macros']),
 				'inventory' => $this->formatHostInventory($host['inventory'])
 			];
 		}
-
-		order_result($this->data['hosts'], 'host');
 	}
 
 	/**
@@ -171,6 +173,8 @@ class CConfigurationExportBuilder {
 	public function buildMaps(array $maps) {
 		$this->data['maps'] = [];
 
+		CArrayHelper::sort($maps, ['name']);
+
 		foreach ($maps as $map) {
 			$tmpSelements = $this->formatMapElements($map['selements']);
 			$this->data['maps'][] = [
@@ -184,6 +188,7 @@ class CConfigurationExportBuilder {
 				'markelements' => $map['markelements'],
 				'show_unack' => $map['show_unack'],
 				'severity_min' => $map['severity_min'],
+				'show_suppressed' => $map['show_suppressed'],
 				'grid_size' => $map['grid_size'],
 				'grid_show' => $map['grid_show'],
 				'grid_align' => $map['grid_align'],
@@ -203,11 +208,11 @@ class CConfigurationExportBuilder {
 				'iconmap' => $map['iconmap'],
 				'urls' => $this->formatMapUrls($map['urls']),
 				'selements' => $tmpSelements,
+				'shapes' => $map['shapes'],
+				'lines' => $map['lines'],
 				'links' => $this->formatMapLinks($map['links'], $tmpSelements)
 			];
 		}
-
-		order_result($this->data['maps'], 'name');
 	}
 
 	/**
@@ -220,6 +225,8 @@ class CConfigurationExportBuilder {
 	protected function formatMappings(array $mappings) {
 		$result = [];
 
+		CArrayHelper::sort($mappings, ['value']);
+
 		foreach ($mappings as $mapping) {
 			$result[] = [
 				'value' => $mapping['value'],
@@ -227,8 +234,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['value']);
-
 		return $result;
 	}
 
@@ -240,14 +245,14 @@ class CConfigurationExportBuilder {
 	public function buildValueMaps(array $valuemaps) {
 		$this->data['value_maps'] = [];
 
+		CArrayHelper::sort($valuemaps, ['name']);
+
 		foreach ($valuemaps as $valuemap) {
 			$this->data['value_maps'][] = [
 				'name' => $valuemap['name'],
 				'mappings' => $this->formatMappings($valuemap['mappings'])
 			];
 		}
-
-		CArrayHelper::sort($this->data['value_maps'], ['name']);
 	}
 
 	/**
@@ -307,6 +312,8 @@ class CConfigurationExportBuilder {
 	protected function formatDiscoveryRules(array $discoveryRules) {
 		$result = [];
 
+		CArrayHelper::sort($discoveryRules, ['key_']);
+
 		foreach ($discoveryRules as $discoveryRule) {
 			$data = [
 				'name' => $discoveryRule['name'],
@@ -324,7 +331,6 @@ class CConfigurationExportBuilder {
 				'snmpv3_authpassphrase' => $discoveryRule['snmpv3_authpassphrase'],
 				'snmpv3_privprotocol' => $discoveryRule['snmpv3_privprotocol'],
 				'snmpv3_privpassphrase' => $discoveryRule['snmpv3_privpassphrase'],
-				'delay_flex' => $discoveryRule['delay_flex'],
 				'params' => $discoveryRule['params'],
 				'ipmi_sensor' => $discoveryRule['ipmi_sensor'],
 				'authtype' => $discoveryRule['authtype'],
@@ -339,17 +345,125 @@ class CConfigurationExportBuilder {
 				'item_prototypes' => $this->formatItems($discoveryRule['itemPrototypes']),
 				'trigger_prototypes' => $this->formatTriggers($discoveryRule['triggerPrototypes']),
 				'graph_prototypes' => $this->formatGraphs($discoveryRule['graphPrototypes']),
-				'host_prototypes' => $this->formatHostPrototypes($discoveryRule['hostPrototypes'])
+				'host_prototypes' => $this->formatHostPrototypes($discoveryRule['hostPrototypes']),
+				'jmx_endpoint' => $discoveryRule['jmx_endpoint'],
+				'timeout' => $discoveryRule['timeout'],
+				'url' => $discoveryRule['url'],
+				'query_fields' => $discoveryRule['query_fields'],
+				'posts' => $discoveryRule['posts'],
+				'status_codes' => $discoveryRule['status_codes'],
+				'follow_redirects' => $discoveryRule['follow_redirects'],
+				'post_type' => $discoveryRule['post_type'],
+				'http_proxy' => $discoveryRule['http_proxy'],
+				'headers' => $discoveryRule['headers'],
+				'retrieve_mode' => $discoveryRule['retrieve_mode'],
+				'request_method' => $discoveryRule['request_method'],
+				'allow_traps' => $discoveryRule['allow_traps'],
+				'ssl_cert_file' => $discoveryRule['ssl_cert_file'],
+				'ssl_key_file' => $discoveryRule['ssl_key_file'],
+				'ssl_key_password' => $discoveryRule['ssl_key_password'],
+				'verify_peer' => $discoveryRule['verify_peer'],
+				'verify_host' => $discoveryRule['verify_host']
 			];
 
 			if (isset($discoveryRule['interface_ref'])) {
 				$data['interface_ref'] = $discoveryRule['interface_ref'];
 			}
 
+			if ($discoveryRule['query_fields']) {
+				$query_fields = [];
+
+				foreach ($discoveryRule['query_fields'] as $query_field) {
+					$query_fields[] = [
+						'name' => key($query_field),
+						'value' => reset($query_field)
+					];
+				}
+
+				$data['query_fields'] = $query_fields;
+			}
+
+			if ($discoveryRule['headers']) {
+				$headers = [];
+
+				foreach ($discoveryRule['headers'] as $name => $value) {
+					$headers[] = compact('name', 'value');
+				}
+
+				$data['headers'] = $headers;
+			}
+
 			$result[] = $data;
 		}
 
-		order_result($result, 'key');
+		return $result;
+	}
+
+	/**
+	 * Format web scenarios.
+	 *
+	 * @param array $httptests
+	 *
+	 * @return array
+	 */
+	protected function formatHttpTests(array $httptests) {
+		$result = [];
+
+		order_result($httptests, 'name');
+
+		foreach ($httptests as $httptest) {
+			$result[] = [
+				'name' => $httptest['name'],
+				'application' => $httptest['application'],
+				'delay' => $httptest['delay'],
+				'attempts' => $httptest['retries'],
+				'agent' => $httptest['agent'],
+				'http_proxy' => $httptest['http_proxy'],
+				'variables' => $httptest['variables'],
+				'headers' => $httptest['headers'],
+				'status' => $httptest['status'],
+				'authentication' => $httptest['authentication'],
+				'http_user' => $httptest['http_user'],
+				'http_password' => $httptest['http_password'],
+				'verify_peer' => $httptest['verify_peer'],
+				'verify_host' => $httptest['verify_host'],
+				'ssl_cert_file' => $httptest['ssl_cert_file'],
+				'ssl_key_file' => $httptest['ssl_key_file'],
+				'ssl_key_password' => $httptest['ssl_key_password'],
+				'steps' => $this->formatHttpSteps($httptest['steps'])
+			];
+		}
+
+		return $result;
+	}
+
+	/**
+	 * Format web scenario steps.
+	 *
+	 * @param array $httpsteps
+	 *
+	 * @return array
+	 */
+	protected function formatHttpSteps(array $httpsteps) {
+		$result = [];
+
+		order_result($httpsteps, 'no');
+
+		foreach ($httpsteps as $httpstep) {
+			$result[] = [
+				'name' => $httpstep['name'],
+				'url' => $httpstep['url'],
+				'query_fields' => $httpstep['query_fields'],
+				'posts' => $httpstep['posts'],
+				'variables' => $httpstep['variables'],
+				'headers' => $httpstep['headers'],
+				'follow_redirects' => $httpstep['follow_redirects'],
+				'retrieve_mode' => $httpstep['retrieve_mode'],
+				'timeout' => $httpstep['timeout'],
+				'required' => $httpstep['required'],
+				'status_codes' => $httpstep['status_codes']
+			];
+		}
 
 		return $result;
 	}
@@ -377,6 +491,8 @@ class CConfigurationExportBuilder {
 	protected function formatGraphs(array $graphs) {
 		$result = [];
 
+		CArrayHelper::sort($graphs, ['name']);
+
 		foreach ($graphs as $graph) {
 			$result[] = [
 				'name' => $graph['name'],
@@ -399,8 +515,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -414,6 +528,8 @@ class CConfigurationExportBuilder {
 	protected function formatHostPrototypes(array $hostPrototypes) {
 		$result = [];
 
+		CArrayHelper::sort($hostPrototypes, ['host']);
+
 		foreach ($hostPrototypes as $hostPrototype) {
 			$result[] = [
 				'host' => $hostPrototype['host'],
@@ -425,8 +541,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		order_result($result, 'host');
-
 		return $result;
 	}
 
@@ -440,7 +554,7 @@ class CConfigurationExportBuilder {
 	protected function formatGroupLinks(array $groupLinks) {
 		$result = [];
 
-		order_result($groupLinks, 'name');
+		CArrayHelper::sort($groupLinks, ['name']);
 
 		foreach ($groupLinks as $groupLink) {
 			$result[] = [
@@ -461,14 +575,14 @@ class CConfigurationExportBuilder {
 	protected function formatGroupPrototypes(array $groupPrototypes) {
 		$result = [];
 
+		CArrayHelper::sort($groupPrototypes, ['name']);
+
 		foreach ($groupPrototypes as $groupPrototype) {
 			$result[] = [
 				'name' => $groupPrototype['name']
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -482,14 +596,14 @@ class CConfigurationExportBuilder {
 	protected function formatTemplateLinkage(array $templates) {
 		$result = [];
 
+		CArrayHelper::sort($templates, ['host']);
+
 		foreach ($templates as $template) {
 			$result[] = [
 				'name' => $template['host']
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -503,21 +617,27 @@ class CConfigurationExportBuilder {
 	protected function formatTriggers(array $triggers) {
 		$result = [];
 
+		CArrayHelper::sort($triggers, ['description', 'expression', 'recovery_expression']);
+
 		foreach ($triggers as $trigger) {
 			$result[] = [
 				'expression' => $trigger['expression'],
+				'recovery_mode' => $trigger['recovery_mode'],
+				'recovery_expression' => $trigger['recovery_expression'],
 				'name' => $trigger['description'],
+				'correlation_mode' => $trigger['correlation_mode'],
+				'correlation_tag' => $trigger['correlation_tag'],
 				'url' => $trigger['url'],
 				'status' => $trigger['status'],
 				'priority' => $trigger['priority'],
 				'description' => $trigger['comments'],
 				'type' => $trigger['type'],
-				'dependencies' => $this->formatDependencies($trigger['dependencies'])
+				'manual_close' => $trigger['manual_close'],
+				'dependencies' => $this->formatDependencies($trigger['dependencies']),
+				'tags' => $this->formatTags($trigger['tags'])
 			];
 		}
 
-		CArrayHelper::sort($result, ['name', 'expression']);
-
 		return $result;
 	}
 
@@ -531,6 +651,8 @@ class CConfigurationExportBuilder {
 	protected function formatHostInterfaces(array $interfaces) {
 		$result = [];
 
+		CArrayHelper::sort($interfaces, ['type', 'ip', 'dns', 'port']);
+
 		foreach ($interfaces as $interface) {
 			$result[] = [
 				'default' => $interface['main'],
@@ -544,8 +666,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['type', 'ip', 'dns', 'port']);
-
 		return $result;
 	}
 
@@ -559,14 +679,14 @@ class CConfigurationExportBuilder {
 	protected function formatGroups(array $groups) {
 		$result = [];
 
+		CArrayHelper::sort($groups, ['name']);
+
 		foreach ($groups as $group) {
 			$result[] = [
 				'name' => $group['name']
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -580,12 +700,13 @@ class CConfigurationExportBuilder {
 	protected function formatItems(array $items) {
 		$result = [];
 
+		CArrayHelper::sort($items, ['key_']);
+
 		foreach ($items as $item) {
 			$data = [
 				'name' => $item['name'],
 				'type' => $item['type'],
 				'snmp_community' => $item['snmp_community'],
-				'multiplier' => $item['multiplier'],
 				'snmp_oid' => $item['snmp_oid'],
 				'key' => $item['key_'],
 				'delay' => $item['delay'],
@@ -595,7 +716,6 @@ class CConfigurationExportBuilder {
 				'value_type' => $item['value_type'],
 				'allowed_hosts' => $item['trapper_hosts'],
 				'units' => $item['units'],
-				'delta' => $item['delta'],
 				'snmpv3_contextname' => $item['snmpv3_contextname'],
 				'snmpv3_securityname' => $item['snmpv3_securityname'],
 				'snmpv3_securitylevel' => $item['snmpv3_securitylevel'],
@@ -603,11 +723,8 @@ class CConfigurationExportBuilder {
 				'snmpv3_authpassphrase' => $item['snmpv3_authpassphrase'],
 				'snmpv3_privprotocol' => $item['snmpv3_privprotocol'],
 				'snmpv3_privpassphrase' => $item['snmpv3_privpassphrase'],
-				'formula' => $item['formula'],
-				'delay_flex' => $item['delay_flex'],
 				'params' => $item['params'],
 				'ipmi_sensor' => $item['ipmi_sensor'],
-				'data_type' => $item['data_type'],
 				'authtype' => $item['authtype'],
 				'username' => $item['username'],
 				'password' => $item['password'],
@@ -618,22 +735,67 @@ class CConfigurationExportBuilder {
 				'inventory_link' => $item['inventory_link'],
 				'applications' => $this->formatApplications($item['applications']),
 				'valuemap' => $item['valuemap'],
-				'logtimefmt' => $item['logtimefmt']
+				'logtimefmt' => $item['logtimefmt'],
+				'preprocessing' => $item['preprocessing'],
+				'jmx_endpoint' => $item['jmx_endpoint'],
+				'timeout' => $item['timeout'],
+				'url' => $item['url'],
+				'query_fields' => $item['query_fields'],
+				'posts' => $item['posts'],
+				'status_codes' => $item['status_codes'],
+				'follow_redirects' => $item['follow_redirects'],
+				'post_type' => $item['post_type'],
+				'http_proxy' => $item['http_proxy'],
+				'headers' => $item['headers'],
+				'retrieve_mode' => $item['retrieve_mode'],
+				'request_method' => $item['request_method'],
+				'output_format' => $item['output_format'],
+				'allow_traps' => $item['allow_traps'],
+				'ssl_cert_file' => $item['ssl_cert_file'],
+				'ssl_key_file' => $item['ssl_key_file'],
+				'ssl_key_password' => $item['ssl_key_password'],
+				'verify_peer' => $item['verify_peer'],
+				'verify_host' => $item['verify_host']
 			];
 
+			$master_item = ($item['type'] == ITEM_TYPE_DEPENDENT) ? ['key' => $item['master_item']['key_']] : [];
+
 			if ($item['flags'] == ZBX_FLAG_DISCOVERY_PROTOTYPE) {
 				$data['application_prototypes'] = $this->formatApplications($item['applicationPrototypes']);
 			}
 
+			$data['master_item'] = $master_item;
+
 			if (isset($item['interface_ref'])) {
 				$data['interface_ref'] = $item['interface_ref'];
 			}
 
+			if ($item['query_fields']) {
+				$query_fields = [];
+
+				foreach ($item['query_fields'] as $query_field) {
+					$query_fields[] = [
+						'name' => key($query_field),
+						'value' => reset($query_field)
+					];
+				}
+
+				$data['query_fields'] = $query_fields;
+			}
+
+			if ($item['headers']) {
+				$headers = [];
+
+				foreach ($item['headers'] as $name => $value) {
+					$headers[] = compact('name', 'value');
+				}
+
+				$data['headers'] = $headers;
+			}
+
 			$result[] = $data;
 		}
 
-		order_result($result, 'key');
-
 		return $result;
 	}
 
@@ -647,14 +809,14 @@ class CConfigurationExportBuilder {
 	protected function formatApplications(array $applications) {
 		$result = [];
 
+		CArrayHelper::sort($applications, ['name']);
+
 		foreach ($applications as $application) {
 			$result[] = [
 				'name' => $application['name']
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -668,6 +830,8 @@ class CConfigurationExportBuilder {
 	protected function formatMacros(array $macros) {
 		$result = [];
 
+		$macros = order_macros($macros, 'macro');
+
 		foreach ($macros as $macro) {
 			$result[] = [
 				'macro' => $macro['macro'],
@@ -675,8 +839,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		$macros = order_macros($result, 'macro');
-
 		return $result;
 	}
 
@@ -690,6 +852,8 @@ class CConfigurationExportBuilder {
 	protected function formatScreens(array $screens) {
 		$result = [];
 
+		CArrayHelper::sort($screens, ['name']);
+
 		foreach ($screens as $screen) {
 			$result[] = [
 				'name' => $screen['name'],
@@ -699,8 +863,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		order_result($result, 'name');
-
 		return $result;
 	}
 
@@ -714,14 +876,37 @@ class CConfigurationExportBuilder {
 	protected function formatDependencies(array $dependencies) {
 		$result = [];
 
+		CArrayHelper::sort($dependencies, ['description', 'expression', 'recovery_expression']);
+
 		foreach ($dependencies as $dependency) {
 			$result[] = [
 				'name' => $dependency['description'],
-				'expression' => $dependency['expression']
+				'expression' => $dependency['expression'],
+				'recovery_expression' => $dependency['recovery_expression']
 			];
 		}
 
-		CArrayHelper::sort($result, ['name', 'expression']);
+		return $result;
+	}
+
+	/**
+	 * Format trigger tags.
+	 *
+	 * @param array $tags
+	 *
+	 * @return array
+	 */
+	protected function formatTags(array $tags) {
+		$result = [];
+
+		CArrayHelper::sort($tags, ['tag', 'value']);
+
+		foreach ($tags as $tag) {
+			$result[] = [
+				'tag' => $tag['tag'],
+				'value' => $tag['value']
+			];
+		}
 
 		return $result;
 	}
@@ -736,6 +921,8 @@ class CConfigurationExportBuilder {
 	protected function formatScreenItems(array $screenItems) {
 		$result = [];
 
+		CArrayHelper::sort($screenItems, ['y', 'x']);
+
 		foreach ($screenItems as $screenItem) {
 			$result[] = [
 				'resourcetype' => $screenItem['resourcetype'],
@@ -758,8 +945,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['y', 'x']);
-
 		return $result;
 	}
 
@@ -773,6 +958,8 @@ class CConfigurationExportBuilder {
 	protected function formatGraphItems(array $graphItems) {
 		$result = [];
 
+		CArrayHelper::sort($graphItems, ['sortorder']);
+
 		foreach ($graphItems as $graphItem) {
 			$result[] = [
 				'sortorder'=> $graphItem['sortorder'],
@@ -785,8 +972,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['sortorder']);
-
 		return $result;
 	}
 
@@ -800,6 +985,8 @@ class CConfigurationExportBuilder {
 	protected function formatMapUrls(array $urls) {
 		$result = [];
 
+		CArrayHelper::sort($urls, ['name', 'url']);
+
 		foreach ($urls as $url) {
 			$result[] = [
 				'name' => $url['name'],
@@ -808,8 +995,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['name', 'url']);
-
 		return $result;
 	}
 
@@ -823,6 +1008,8 @@ class CConfigurationExportBuilder {
 	protected function formatMapElementUrls(array $urls) {
 		$result = [];
 
+		CArrayHelper::sort($urls, ['name', 'url']);
+
 		foreach ($urls as $url) {
 			$result[] = [
 				'name' => $url['name'],
@@ -830,8 +1017,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['name', 'url']);
-
 		return $result;
 	}
 
@@ -860,7 +1045,7 @@ class CConfigurationExportBuilder {
 			$link['selementpos1'] = $flipped_selements[$link['selementid1']];
 			$link['selementpos2'] = $flipped_selements[$link['selementid2']];
 
-			// Sort selements positons asc.
+			// Sort selements by position asc.
 			if ($link['selementpos2'] < $link['selementpos1']) {
 				zbx_swap($link['selementpos1'], $link['selementpos2']);
 			}
@@ -896,10 +1081,11 @@ class CConfigurationExportBuilder {
 		foreach ($linktriggers as &$linktrigger) {
 			$linktrigger['description'] = $linktrigger['triggerid']['description'];
 			$linktrigger['expression'] = $linktrigger['triggerid']['expression'];
+			$linktrigger['recovery_expression'] = $linktrigger['triggerid']['recovery_expression'];
 		}
 		unset($linktrigger);
 
-		CArrayHelper::sort($linktriggers, ['description', 'expression']);
+		CArrayHelper::sort($linktriggers, ['description', 'expression', 'recovery_expression']);
 
 		foreach ($linktriggers as $linktrigger) {
 			$result[] = [
@@ -922,6 +1108,8 @@ class CConfigurationExportBuilder {
 	protected function formatMapElements(array $elements) {
 		$result = [];
 
+		CArrayHelper::sort($elements, ['y', 'x']);
+
 		foreach ($elements as $element) {
 			$result[] = [
 				'elementtype' => $element['elementtype'],
@@ -936,7 +1124,7 @@ class CConfigurationExportBuilder {
 				'viewtype' => $element['viewtype'],
 				'use_iconmap' => $element['use_iconmap'],
 				'selementid' => $element['selementid'],
-				'element' => $element['elementid'],
+				'elements' => $element['elements'],
 				'icon_off' => $element['iconid_off'],
 				'icon_on' => $element['iconid_on'],
 				'icon_disabled' => $element['iconid_disabled'],
@@ -946,8 +1134,6 @@ class CConfigurationExportBuilder {
 			];
 		}
 
-		CArrayHelper::sort($result, ['y', 'x']);
-
 		return $result;
 	}
 }
