@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2016 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -111,6 +111,10 @@ class CImportDataAdapter {
 
 				if (array_key_exists('interfaces', $host)) {
 					foreach ($host['interfaces'] as $inum => $interface) {
+						if ($interface['type'] != INTERFACE_TYPE_SNMP) {
+							unset($interface['bulk']);
+						}
+
 						$host['interfaces'][$inum] = CArrayHelper::renameKeys($interface, ['default' => 'main']);
 					}
 				}
