@@ -1,141 +1,152 @@
 <script type="text/x-jquery-tmpl" id="dcheckRowTPL">
-	<tr id="dcheckRow_#{dcheckid}">
-		<td id="dcheckCell_#{dcheckid}">
-			<span class="bold">#{name}</span>
-		</td>
-		<td>
-			<input type="button" class="input link_menu" name="edit" value="<?php echo CHtml::encode(_('Edit')); ?>"
-				onclick="javascript: showNewCheckForm(null, null, '#{dcheckid}');" />
-		</td>
-		<td>
-			<input type="button" class="input link_menu" name="remove" value="<?php echo CHtml::encode(_('Remove')); ?>"
-				onclick="javascript: removeDCheckRow('#{dcheckid}');" />
-		</td>
-	</tr>
+	<?= (new CRow([
+			(new CCol(
+				(new CDiv('#{name}'))->addClass(ZBX_STYLE_WORDWRAP)
+			))->setId('dcheckCell_#{dcheckid}'),
+			(new CHorList([
+				(new CButton(null, _('Edit')))
+					->addClass(ZBX_STYLE_BTN_LINK)
+					->onClick("javascript: showNewCheckForm(null, '#{dcheckid}');"),
+				(new CButton(null, _('Remove')))
+					->addClass(ZBX_STYLE_BTN_LINK)
+					->onClick("javascript: removeDCheckRow('#{dcheckid}');")
+			]))->addClass(ZBX_STYLE_NOWRAP)
+		]))
+			->setId('dcheckRow_#{dcheckid}')
+			->toString()
+	?>
 </script>
 <script type="text/x-jquery-tmpl" id="uniqRowTPL">
-	<div id="uniqueness_criteria_row_#{dcheckid}">
-		<input type="radio" id="uniqueness_criteria_#{dcheckid}" name="uniqueness_criteria" class="input radio"
-			value="#{dcheckid}" />
-		<label for="uniqueness_criteria_#{dcheckid}">#{name}</label>
-	</div>
+	<?=	(new CListItem([
+			(new CInput('radio', 'uniqueness_criteria', '#{dcheckid}'))
+				->addClass(ZBX_STYLE_CHECKBOX_RADIO)
+				->setId('uniqueness_criteria_#{dcheckid}'),
+			(new CLabel([new CSpan(), '#{name}'], 'uniqueness_criteria_#{dcheckid}'))
+				->addClass(ZBX_STYLE_WORDWRAP)
+		]))
+			->setId('uniqueness_criteria_row_#{dcheckid}')
+			->toString()
+	?>
 </script>
 <script type="text/x-jquery-tmpl" id="newDCheckTPL">
-	<div id="new_check_form">
-		<div class="objectgroup inlineblock border_dotted ui-corner-all">
-			<table class="formElementTable">
-				<tbody>
-				<tr>
-					<td><label for="type"><?php echo _('Check type'); ?></label></td>
-					<td><select id="type" name="type" class="input select"></select></td>
-				</tr>
-				<tr id="newCheckPortsRow" class="hidden">
-					<td><label for="ports"><?php echo _('Port range'); ?></label></td>
-					<td>
-						<input type="text" id="ports" name="ports" value="" class="input text" size="16" maxlength="255">
-					</td>
-				</tr>
-				<tr id="newCheckCommunityRow" class="hidden">
-					<td><label for="snmp_community"><?php echo _('SNMP community'); ?></label></td>
-					<td><input type="text" id="snmp_community" name="snmp_community" value="" class="input text"
-							size="20" maxlength="255"></td>
-				</tr>
-				<tr id="newCheckKeyRow" class="hidden">
-					<td><label for="key_"><?php echo _('SNMP Key'); ?></label></td>
-					<td>
-						<input type="text" id="key_" name="key_" value="" class="input text" size="20" maxlength="255">
-					</td>
-				</tr>
-				<tr id="newCheckContextRow" class="hidden">
-					<td><label for="snmpv3_contextname"><?php echo _('Context name'); ?></label></td>
-					<td>
-						<input type="text" id="snmpv3_contextname" name="snmpv3_contextname" value="" class="input text" size="20" maxlength="255">
-					</td>
-				</tr>
-				<tr id="newCheckSecNameRow" class="hidden">
-					<td><label for="snmpv3_securityname"><?php echo _('Security name'); ?></label></td>
-					<td><input type="text" id="snmpv3_securityname" name="snmpv3_securityname" value=""
-							class="input text" size="20" maxlength="64"></td>
-				</tr>
-				<tr id="newCheckSecLevRow" class="hidden">
-					<td><label for="snmpv3_securitylevel"><?php echo _('Security level'); ?></label></td>
-					<td>
-						<select id="snmpv3_securitylevel" name="snmpv3_securitylevel" class="input select" size="1">
-							<option value="0"><?php echo 'noAuthNoPriv'; ?> </option>
-							<option value="1"><?php echo 'authNoPriv'; ?> </option>
-							<option value="2"><?php echo 'authPriv'; ?> </option>
-						</select>
-					</td>
-				</tr>
-				<tr id="newCheckAuthProtocolRow" class="hidden">
-					<td><label for="snmpv3_authprotocol"><?php echo _('Authentication protocol'); ?></label></td>
-					<td>
-						<div class="jqueryinputset">
-							<input name="snmpv3_authprotocol" id="snmpv3_authprotocol_0" type="radio" checked="checked"
-								value="<?php echo ITEM_AUTHPROTOCOL_MD5; ?>" />
-							<input name="snmpv3_authprotocol" id="snmpv3_authprotocol_1" type="radio"
-								value="<?php echo ITEM_AUTHPROTOCOL_SHA; ?>" />
-							<label for="snmpv3_authprotocol_0"><?php echo _('MD5'); ?></label><label for="snmpv3_authprotocol_1"><?php echo _('SHA'); ?></label>
-						</div>
-					</td>
-				</tr>
-				<tr id="newCheckAuthPassRow" class="hidden">
-					<td><label for="snmpv3_authpassphrase"><?php echo _('Authentication passphrase'); ?></label></td>
-					<td><input type="text" id="snmpv3_authpassphrase" name="snmpv3_authpassphrase" value=""
-							class="input text" size="20" maxlength="64"></td>
-				</tr>
-				<tr id="newCheckPrivProtocolRow" class="hidden">
-					<td><label for="snmpv3_authprotocol"><?php echo _('Authentication protocol'); ?></label></td>
-					<td>
-						<div class="jqueryinputset">
-							<input name="snmpv3_privprotocol" id="snmpv3_privprotocol_0" type="radio" checked="checked"
-								value="<?php echo ITEM_PRIVPROTOCOL_DES; ?>" />
-							<input name="snmpv3_privprotocol" id="snmpv3_privprotocol_1" type="radio"
-								value="<?php echo ITEM_PRIVPROTOCOL_AES; ?>" />
-							<label for="snmpv3_privprotocol_0"><?php echo _('DES'); ?></label><label for="snmpv3_privprotocol_1"><?php echo _('AES'); ?></label>
-						</div>
-					</td>
-				</tr>
-				<tr id="newCheckPrivPassRow" class="hidden">
-					<td><label for="snmpv3_privpassphrase"><?php echo _('Privacy passphrase'); ?></label></td>
-					<td><input type="text" id="snmpv3_privpassphrase" name="snmpv3_privpassphrase" value=""
-							class="input text" size="20" maxlength="64"></td>
-				</tr>
-				</tbody>
-			</table>
-			<table class="formElementTable">
-				<tr>
-					<td>
-						<input type="button" id="add_new_dcheck" name="add_new_dcheck" class="input button link_menu"
-							value="<?php echo CHtml::encode(_('Add')); ?>" />
-					</td>
-					<td>
-						<input type="button" id="cancel_new_dcheck" name="cancel_new_dcheck" class="input button link_menu"
-							value="<?php echo CHtml::encode(_('Cancel')); ?>" />
-					</td>
-				</tr>
-			</table>
-		</div>
-	</div>
+<?=
+	(new CDiv(
+		(new CDiv([
+			(new CFormList())
+				->addRow(
+					(new CLabel(_('Check type'), 'type')),
+					(new CComboBox('type'))
+				)
+				->addRow(
+					(new CLabel(_('Port range'), 'ports'))->setAsteriskMark(),
+					(new CTextBox('ports'))
+						->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+						->setAriaRequired(),
+					'newCheckPortsRow'
+				)
+				->addRow(
+					(new CLabel(_('SNMP community'), 'snmp_community'))->setAsteriskMark(),
+					(new CTextBox('snmp_community'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAriaRequired(),
+					'newCheckCommunityRow'
+				)
+				->addRow(
+					(new CLabel(_('Key'), 'key_'))->setAsteriskMark(),
+					(new CTextBox('key_'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAriaRequired(),
+					'newCheckKeyRow'
+				)
+				->addRow(
+					(new CLabel(_('SNMP OID'), 'snmp_oid'))->setAsteriskMark(),
+					(new CTextBox('snmp_oid'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAriaRequired()
+						->setAttribute('maxlength', 512),
+					'new_check_snmp_oid_row'
+				)
+				->addRow(
+					(new CLabel(_('Context name'), 'snmpv3_contextname')),
+					(new CTextBox('snmpv3_contextname'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH),
+					'newCheckContextRow'
+				)
+				->addRow(
+					(new CLabel(_('Security name'), 'snmpv3_securityname')),
+					(new CTextBox('snmpv3_securityname'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAttribute('maxlength', 64),
+					'newCheckSecNameRow'
+				)
+				->addRow(
+					new CLabel(_('Security level'), 'snmpv3_securitylevel'),
+					new CComboBox('snmpv3_securitylevel', null, null, [
+						ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV => 'noAuthNoPriv',
+						ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV => 'authNoPriv',
+						ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV => 'authPriv'
+					]),
+					'newCheckSecLevRow'
+				)
+				->addRow(
+					(new CLabel(_('Authentication protocol'), 'snmpv3_authprotocol')),
+					(new CRadioButtonList('snmpv3_authprotocol', ITEM_AUTHPROTOCOL_MD5))
+						->addValue(_('MD5'), ITEM_AUTHPROTOCOL_MD5, 'snmpv3_authprotocol_'.ITEM_AUTHPROTOCOL_MD5)
+						->addValue(_('SHA'), ITEM_AUTHPROTOCOL_SHA, 'snmpv3_authprotocol_'.ITEM_AUTHPROTOCOL_SHA)
+						->setModern(true),
+					'newCheckAuthProtocolRow'
+				)
+				->addRow(
+					(new CLabel(_('Authentication passphrase'), 'snmpv3_authpassphrase')),
+					(new CTextBox('snmpv3_authpassphrase'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAttribute('maxlength', 64),
+					'newCheckAuthPassRow'
+				)
+				->addRow(
+					(new CLabel(_('Privacy protocol'), 'snmpv3_privprotocol')),
+					(new CRadioButtonList('snmpv3_privprotocol', ITEM_PRIVPROTOCOL_DES))
+						->addValue(_('DES'), ITEM_PRIVPROTOCOL_DES, 'snmpv3_privprotocol_'.ITEM_PRIVPROTOCOL_DES)
+						->addValue(_('AES'), ITEM_PRIVPROTOCOL_AES, 'snmpv3_privprotocol_'.ITEM_PRIVPROTOCOL_AES)
+						->setModern(true),
+					'newCheckPrivProtocolRow'
+				)
+				->addRow(
+					(new CLabel(_('Privacy passphrase'), 'snmpv3_privpassphrase'))->setAsteriskMark(),
+					(new CTextBox('snmpv3_privpassphrase'))
+						->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+						->setAriaRequired()
+						->setAttribute('maxlength', 64),
+					'newCheckPrivPassRow'
+				),
+			(new CHorList([
+				(new CButton('add_new_dcheck', _('Add')))->addClass(ZBX_STYLE_BTN_LINK),
+				(new CButton('cancel_new_dcheck', _('Cancel')))->addClass(ZBX_STYLE_BTN_LINK)
+			]))
+		]))
+			->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+			->addStyle('width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px')
+	))->setId('new_check_form')
+?>
 </script>
 <script type="text/javascript">
 	var ZBX_SVC = {
-		ssh: <?php echo SVC_SSH; ?>,
-		ldap: <?php echo SVC_LDAP; ?>,
-		smtp: <?php echo SVC_SMTP; ?>,
-		ftp: <?php echo SVC_FTP; ?>,
-		http: <?php echo SVC_HTTP; ?>,
-		pop: <?php echo SVC_POP; ?>,
-		nntp: <?php echo SVC_NNTP; ?>,
-		imap: <?php echo SVC_IMAP; ?>,
-		tcp: <?php echo SVC_TCP; ?>,
-		agent: <?php echo SVC_AGENT; ?>,
-		snmpv1: <?php echo SVC_SNMPv1; ?>,
-		snmpv2: <?php echo SVC_SNMPv2c; ?>,
-		snmpv3: <?php echo SVC_SNMPv3; ?>,
-		icmp: <?php echo SVC_ICMPPING; ?>,
-		https: <?php echo SVC_HTTPS; ?>,
-		telnet: <?php echo SVC_TELNET; ?>
+		ssh: <?= SVC_SSH ?>,
+		ldap: <?= SVC_LDAP ?>,
+		smtp: <?= SVC_SMTP ?>,
+		ftp: <?= SVC_FTP ?>,
+		http: <?= SVC_HTTP ?>,
+		pop: <?= SVC_POP ?>,
+		nntp: <?= SVC_NNTP ?>,
+		imap: <?= SVC_IMAP ?>,
+		tcp: <?= SVC_TCP ?>,
+		agent: <?= SVC_AGENT ?>,
+		snmpv1: <?= SVC_SNMPv1 ?>,
+		snmpv2: <?= SVC_SNMPv2c ?>,
+		snmpv3: <?= SVC_SNMPv3 ?>,
+		icmp: <?= SVC_ICMPPING ?>,
+		https: <?= SVC_HTTPS ?>,
+		telnet: <?= SVC_TELNET ?>
 	};
 
 	var ZBX_CHECKLIST = {};
@@ -166,22 +177,22 @@
 
 	function discoveryCheckTypeToString(svcPort) {
 		var defPorts = {};
-		defPorts[ZBX_SVC.ftp] = <?php echo CJs::encodeJson(_('FTP')); ?>;
-		defPorts[ZBX_SVC.http] = <?php echo CJs::encodeJson(_('HTTP')); ?>;
-		defPorts[ZBX_SVC.https] = <?php echo CJs::encodeJson(_('HTTPS')); ?>;
-		defPorts[ZBX_SVC.icmp] = <?php echo CJs::encodeJson(_('ICMP ping')); ?>;
-		defPorts[ZBX_SVC.imap] = <?php echo CJs::encodeJson(_('IMAP')); ?>;
-		defPorts[ZBX_SVC.tcp] = <?php echo CJs::encodeJson(_('TCP')); ?>;
-		defPorts[ZBX_SVC.ldap] = <?php echo CJs::encodeJson(_('LDAP')); ?>;
-		defPorts[ZBX_SVC.nntp] = <?php echo CJs::encodeJson(_('NNTP')); ?>;
-		defPorts[ZBX_SVC.pop] = <?php echo CJs::encodeJson(_('POP')); ?>;
-		defPorts[ZBX_SVC.snmpv1] = <?php echo CJs::encodeJson(_('SNMPv1 agent')); ?>;
-		defPorts[ZBX_SVC.snmpv2] = <?php echo CJs::encodeJson(_('SNMPv2 agent')); ?>;
-		defPorts[ZBX_SVC.snmpv3] = <?php echo CJs::encodeJson(_('SNMPv3 agent')); ?>;
-		defPorts[ZBX_SVC.smtp] = <?php echo CJs::encodeJson(_('SMTP')); ?>;
-		defPorts[ZBX_SVC.ssh] = <?php echo CJs::encodeJson(_('SSH')); ?>;
-		defPorts[ZBX_SVC.telnet] = <?php echo CJs::encodeJson(_('Telnet')); ?>;
-		defPorts[ZBX_SVC.agent] = <?php echo CJs::encodeJson(_('Zabbix agent')); ?>;
+		defPorts[ZBX_SVC.ftp] = <?= CJs::encodeJson(_('FTP')) ?>;
+		defPorts[ZBX_SVC.http] = <?= CJs::encodeJson(_('HTTP')) ?>;
+		defPorts[ZBX_SVC.https] = <?= CJs::encodeJson(_('HTTPS')) ?>;
+		defPorts[ZBX_SVC.icmp] = <?= CJs::encodeJson(_('ICMP ping')) ?>;
+		defPorts[ZBX_SVC.imap] = <?= CJs::encodeJson(_('IMAP')) ?>;
+		defPorts[ZBX_SVC.tcp] = <?= CJs::encodeJson(_('TCP')) ?>;
+		defPorts[ZBX_SVC.ldap] = <?= CJs::encodeJson(_('LDAP')) ?>;
+		defPorts[ZBX_SVC.nntp] = <?= CJs::encodeJson(_('NNTP')) ?>;
+		defPorts[ZBX_SVC.pop] = <?= CJs::encodeJson(_('POP')) ?>;
+		defPorts[ZBX_SVC.snmpv1] = <?= CJs::encodeJson(_('SNMPv1 agent')) ?>;
+		defPorts[ZBX_SVC.snmpv2] = <?= CJs::encodeJson(_('SNMPv2 agent')) ?>;
+		defPorts[ZBX_SVC.snmpv3] = <?= CJs::encodeJson(_('SNMPv3 agent')) ?>;
+		defPorts[ZBX_SVC.smtp] = <?= CJs::encodeJson(_('SMTP')) ?>;
+		defPorts[ZBX_SVC.ssh] = <?= CJs::encodeJson(_('SSH')) ?>;
+		defPorts[ZBX_SVC.telnet] = <?= CJs::encodeJson(_('Telnet')) ?>;
+		defPorts[ZBX_SVC.agent] = <?= CJs::encodeJson(_('Zabbix agent')) ?>;
 
 		if (typeof svcPort === 'undefined') {
 			return defPorts;
@@ -189,7 +200,23 @@
 
 		svcPort = parseInt(svcPort, 10);
 
-		return isset(svcPort, defPorts) ? defPorts[svcPort] : <?php echo CJs::encodeJson(_('Unknown')); ?>;
+		return isset(svcPort, defPorts) ? defPorts[svcPort] : <?= CJs::encodeJson(_('Unknown')) ?>;
+	}
+
+	/**
+	 * Checks if type of SNMP.
+	 *
+	 * @param integer type
+	 *
+	 * @return bool
+	 */
+	function typeOfSnmp(type) {
+		var types = {};
+		types[ZBX_SVC.snmpv1] = true;
+		types[ZBX_SVC.snmpv2] = true;
+		types[ZBX_SVC.snmpv3] = true;
+
+		return (typeof types[type] != 'undefined');
 	}
 
 	function toggleInputs(id, state) {
@@ -280,7 +307,7 @@
 				}
 
 				// update check name
-				jQuery('#dcheckCell_' + value.dcheckid + ' .bold').text(value['name']);
+				jQuery('#dcheckCell_' + value.dcheckid + ' .wordwrap').text(value['name']);
 			}
 
 			// update device uniqueness criteria
@@ -288,11 +315,14 @@
 				uniquenessCriteria = jQuery('#uniqueness_criteria_row_' + value.dcheckid);
 
 			if (jQuery.inArray(parseInt(value.type, 10), availableDeviceTypes) > -1) {
+				var new_uniqueness_criteria = uniqRowTpl.evaluate(value);
 				if (uniquenessCriteria.length) {
-					jQuery('label[for=uniqueness_criteria_' + value.dcheckid + ']').text(value['name']);
+					var checked_id = jQuery('input:radio[name=uniqueness_criteria]:checked').attr('id');
+					uniquenessCriteria.replaceWith(new_uniqueness_criteria);
+					jQuery('#' + checked_id).prop('checked', true);
 				}
 				else {
-					jQuery('#uniqList').append(uniqRowTpl.evaluate(value));
+					jQuery('#uniqueness_criteria').append(new_uniqueness_criteria);
 				}
 			}
 			else {
@@ -314,19 +344,15 @@
 		var obj = jQuery('#uniqueness_criteria_' + dcheckid);
 
 		if (obj.length) {
-			if (obj.attr('checked') == 'checked') {
+			if (obj.is(':checked')) {
 				selectUniquenessCriteriaDefault();
 			}
 
 			jQuery('#uniqueness_criteria_row_' + dcheckid).remove();
 		}
-
-		if (IE8) {
-			jQuery('#dcheckList').find('table').addClass('ie8fix-inline').removeClass('ie8fix-inline');
-		}
 	}
 
-	function showNewCheckForm(e, dcheckType, dcheckId) {
+	function showNewCheckForm(e, dcheckId) {
 		var isUpdate = (typeof dcheckId !== 'undefined');
 
 		// remove existing form
@@ -347,12 +373,12 @@
 
 			// button "add"
 			jQuery('#add_new_dcheck').click(function() {
-				saveNewDCheckForm(dcheckId);
+				saveNewDCheckForm(dcheckId, this);
 			});
 
 			// rename button to "update"
 			if (isUpdate) {
-				jQuery('#add_new_dcheck').val(<?php echo CJs::encodeJson(_('Update')); ?>);
+				jQuery('#add_new_dcheck').text(<?= CJs::encodeJson(_('Update')) ?>);
 			}
 
 			// button "remove" form
@@ -384,7 +410,10 @@
 
 		// restore form values
 		if (isUpdate) {
-			jQuery('#dcheckCell_' + dcheckId + ' input').each(function(i, item) {
+			var dcheck_inputs = jQuery('#dcheckCell_' + dcheckId + ' input'),
+				check_type = dcheck_inputs.filter('[name="dchecks[' + dcheckId + '][type]"]').val();
+
+			dcheck_inputs.each(function(i, item) {
 				var itemObj = jQuery(item);
 
 				var name = itemObj.attr('name').replace('dchecks[' + dcheckId + '][', '');
@@ -392,7 +421,14 @@
 
 				// ignore "name" value because it is virtual
 				if (name !== 'name') {
-					jQuery('#' + name).val(itemObj.val());
+					if(name == 'key_' && typeOfSnmp(check_type)) {
+						// Use key_ value in snmp_oid input.
+
+						jQuery('#snmp_oid').val(itemObj.val());
+					}
+					else {
+						jQuery('#' + name).val(itemObj.val());
+					}
 
 					// set radio button value
 					var radioObj = jQuery('input[name=' + name + ']');
@@ -412,12 +448,6 @@
 	function updateNewDCheckType(dcheckId) {
 		var dcheckType = parseInt(jQuery('#type').val(), 10);
 
-		var keyRowTypes = {};
-		keyRowTypes[ZBX_SVC.agent] = true;
-		keyRowTypes[ZBX_SVC.snmpv1] = true;
-		keyRowTypes[ZBX_SVC.snmpv2] = true;
-		keyRowTypes[ZBX_SVC.snmpv3] = true;
-
 		var comRowTypes = {};
 		comRowTypes[ZBX_SVC.snmpv1] = true;
 		comRowTypes[ZBX_SVC.snmpv2] = true;
@@ -426,16 +456,8 @@
 		secNameRowTypes[ZBX_SVC.snmpv3] = true;
 
 		toggleInputs('newCheckPortsRow', (ZBX_SVC.icmp != dcheckType));
-		toggleInputs('newCheckKeyRow', isset(dcheckType, keyRowTypes));
-
-		if (isset(dcheckType, keyRowTypes)) {
-			var caption = (dcheckType == ZBX_SVC.agent)
-				? <?php echo CJs::encodeJson(_('Key')); ?>
-				: <?php echo CJs::encodeJson(_('SNMP OID')); ?>;
-
-			jQuery('#newCheckKeyRow label').text(caption);
-		}
-
+		toggleInputs('newCheckKeyRow', dcheckType == ZBX_SVC.agent);
+		toggleInputs('new_check_snmp_oid_row', typeOfSnmp(dcheckType));
 		toggleInputs('newCheckCommunityRow', isset(dcheckType, comRowTypes));
 		toggleInputs('newCheckSecNameRow', isset(dcheckType, secNameRowTypes));
 		toggleInputs('newCheckSecLevRow', isset(dcheckType, secNameRowTypes));
@@ -485,35 +507,34 @@
 		secNameRowTypes[ZBX_SVC.snmpv3] = true;
 
 		var showAuthProtocol = (isset(dcheckType, secNameRowTypes)
-			&& (dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV; ?>
-				|| dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV; ?>));
+			&& (dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV ?>
+				|| dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV ?>));
 		var showAuthPass = (isset(dcheckType, secNameRowTypes)
-			&& (dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV; ?>
-				|| dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV; ?>));
+			&& (dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV ?>
+				|| dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV ?>));
 		var showPrivProtocol = (isset(dcheckType, secNameRowTypes)
-			&& dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV; ?>);
+			&& dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV ?>);
 		var showPrivPass = (isset(dcheckType, secNameRowTypes)
-			&& dcheckSecLevType == <?php echo ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV; ?>);
+			&& dcheckSecLevType == <?= ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV ?>);
 
 		toggleInputs('newCheckAuthProtocolRow', showAuthProtocol);
 		toggleInputs('newCheckAuthPassRow', showAuthPass);
 		toggleInputs('newCheckPrivProtocolRow', showPrivProtocol);
 		toggleInputs('newCheckPrivPassRow', showPrivPass);
-
-		if (showAuthProtocol) {
-			jQuery('#newCheckAuthProtocolRow .jqueryinputset').buttonset();
-		}
-		if (showPrivProtocol) {
-			jQuery('#newCheckPrivProtocolRow .jqueryinputset').buttonset();
-		}
-
-		if (IE8) {
-			jQuery('#type').closest('li').addClass('ie8fix-inline').removeClass('ie8fix-inline');
-		}
 	}
 
-	function saveNewDCheckForm(dcheckId) {
+	/**
+	 * Validates discovery check.
+	 *
+	 * @param {string} dcheckId            Discovery rule check id.
+	 * @param {HTMLElement} trigger_elmnt  Element that triggered this action.
+	 */
+	function saveNewDCheckForm(dcheckId, trigger_elmnt) {
 		var dCheck = jQuery('#new_check_form :input:enabled').serializeJSON();
+		if (typeof dCheck.snmp_oid != 'undefined') {
+			dCheck.key_ = dCheck.snmp_oid;
+			delete dCheck.snmp_oid;
+		}
 
 		// get check id
 		dCheck.dcheckid = (typeof dcheckId === 'undefined') ? getUniqueId() : dcheckId;
@@ -542,13 +563,19 @@
 							|| ZBX_CHECKLIST[zbxDcheckId]['snmpv3_securityname'] === dCheck['snmpv3_securityname'])
 						&& (typeof dCheck['snmpv3_contextname'] === 'undefined'
 							|| ZBX_CHECKLIST[zbxDcheckId]['snmpv3_contextname'] === dCheck['snmpv3_contextname'])) {
-					showModalWindow(
-						t(<?php echo CJs::encodeJson(_('Discovery check error')); ?>),
-						<?php echo CJs::encodeJson(_('Check already exists.')); ?>,
-						[{text: t(<?php echo CJs::encodeJson(_('Close')); ?>), click: function() {
-							jQuery(this).dialog('destroy');
-						}}]
-					);
+
+					overlayDialogue({
+						'title': <?= CJs::encodeJson(_('Discovery check error')) ?>,
+						'content': jQuery('<span>').text(<?= CJs::encodeJson(_('Check already exists.')) ?>),
+						'buttons': [
+							{
+								'title': <?= CJs::encodeJson(_('Cancel')) ?>,
+								'cancel': true,
+								'focused': true,
+								'action': function() {}
+							}
+						]
+					}, trigger_elmnt);
 
 					return null;
 				}
@@ -572,11 +599,11 @@
 			case ZBX_SVC.snmpv1:
 			case ZBX_SVC.snmpv2:
 				if (dCheck.snmp_community == '') {
-					validationErrors.push(<?php echo CJs::encodeJson(_('Incorrect SNMP community.')); ?>);
+					validationErrors.push(<?= CJs::encodeJson(_('Incorrect SNMP community.')) ?>);
 				}
 			case ZBX_SVC.snmpv3:
 				if (dCheck.key_ == '') {
-					validationErrors.push(<?php echo CJs::encodeJson(_('Incorrect SNMP OID.')); ?>);
+					validationErrors.push(<?= CJs::encodeJson(_('Incorrect SNMP OID.')) ?>);
 				}
 				break;
 		}
@@ -606,14 +633,20 @@
 					}
 				},
 				error: function() {
-					showModalWindow(
-						t(<?php echo CJs::encodeJson(_('Discovery check error')); ?>),
-						<?php echo CJs::encodeJson(_('Cannot validate discovery check: invalid request or connection to Zabbix server failed.')); ?>,
-						[{text: t(<?php echo CJs::encodeJson(_('Close')); ?>), click: function() {
-							jQuery(this).dialog('destroy');
-						}}]
-					);
-
+					overlayDialogue({
+						'title': <?= CJs::encodeJson(_('Discovery check error')) ?>,
+						'content': jQuery('<span>').text(<?= CJs::encodeJson(
+							_('Cannot validate discovery check: invalid request or connection to Zabbix server failed.')
+						) ?>),
+						'buttons': [
+							{
+								'title': <?= CJs::encodeJson(_('Cancel')) ?>,
+								'cancel': true,
+								'focused': true,
+								'action': function() {}
+							}
+						]
+					}, trigger_elmnt);
 					jQuery('#add_new_dcheck').prop('disabled', false);
 				}
 			});
@@ -623,13 +656,27 @@
 			jQuery('#add_new_dcheck').prop('disabled', false);
 
 			if (validationErrors.length) {
-				showModalWindow(
-					t(<?php echo CJs::encodeJson(_('Discovery check error')); ?>),
-					validationErrors.join('\n'),
-					[{text: t(<?php echo CJs::encodeJson(_('Close')); ?>), click: function() {
-						jQuery(this).dialog('destroy');
-					}}]
-				);
+				var content = jQuery('<span>');
+
+				for (var i = 0; i < validationErrors.length; i++) {
+					if (content.html() !== '') {
+						content.append(jQuery('<br>'));
+					}
+					content.append(jQuery('<span>').text(validationErrors[i]));
+				}
+
+				overlayDialogue({
+					'title': <?= CJs::encodeJson(_('Discovery check error')) ?>,
+					'content': content,
+					'buttons': [
+						{
+							'title': <?= CJs::encodeJson(_('Cancel')) ?>,
+							'cancel': true,
+							'focused': true,
+							'action': function() {}
+						}
+					]
+				}, trigger_elmnt);
 			}
 			else {
 				dCheck.name = jQuery('#type :selected').text();
@@ -653,29 +700,18 @@
 	}
 
 	jQuery(document).ready(function() {
-		addPopupValues(<?php echo zbx_jsvalue(array_values($this->data['drule']['dchecks'])); ?>);
+		addPopupValues(<?= zbx_jsvalue(array_values($this->data['drule']['dchecks'])) ?>);
 
-		jQuery("input:radio[name='uniqueness_criteria'][value=<?php echo zbx_jsvalue($this->data['drule']['uniqueness_criteria']); ?>]").attr('checked', 'checked');
+		jQuery("input:radio[name='uniqueness_criteria'][value=<?= zbx_jsvalue($this->data['drule']['uniqueness_criteria']) ?>]").attr('checked', 'checked');
 
 		jQuery('#newCheck').click(showNewCheckForm);
 		jQuery('#clone').click(function() {
-			jQuery('#update').val(<?php echo CJs::encodeJson(_('Add')); ?>).attr({id: 'add', name: 'add'});
+			jQuery('#update')
+				.text(<?= CJs::encodeJson(_('Add')) ?>)
+				.attr({id: 'add', name: 'add'});
 			jQuery('#druleid, #delete, #clone').remove();
-			jQuery('#cancel').addClass('ui-corner-left');
 			jQuery('#form').val('clone');
 			jQuery('#name').focus();
 		});
 	});
-
-	(function($) {
-		$.fn.serializeJSON = function() {
-			var json = {};
-
-			jQuery.map($(this).serializeArray(), function(n, i) {
-				json[n['name']] = n['value'];
-			});
-
-			return json;
-		};
-	})(jQuery);
 </script>
