@@ -1167,7 +1167,7 @@ int	zbx_ipc_socket_open(zbx_ipc_socket_t *csocket, const char *service_name, int
 
 	while (0 != connect(csocket->fd, (struct sockaddr*)&addr, sizeof(addr)))
 	{
-		if (time(NULL) - start > timeout)
+		if (0 == timeout || time(NULL) - start > timeout)
 		{
 			*error = zbx_dsprintf(*error, "Cannot connect to service \"%s\": %s.", service_name,
 					zbx_strerror(errno));
