@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -576,7 +576,7 @@ static void	ipmi_manager_process_poller_queue(zbx_ipmi_manager_t *manager, zbx_i
 			case ZBX_IPC_IPMI_CLEANUP_REQUEST:
 				break;
 			case ZBX_IPC_IPMI_VALUE_REQUEST:
-				if (NULL == (host = zbx_hashset_search(&manager->hosts, &request->hostid)))
+				if (NULL == (host = (zbx_ipmi_manager_host_t *)zbx_hashset_search(&manager->hosts, &request->hostid)))
 				{
 					THIS_SHOULD_NEVER_HAPPEN;
 					ipmi_request_free(request);
@@ -618,7 +618,7 @@ static zbx_ipmi_manager_host_t	*ipmi_manager_cache_host(zbx_ipmi_manager_t *mana
 		zbx_ipmi_manager_host_t	host_local;
 
 		host_local.hostid = hostid;
-		host = zbx_hashset_insert(&manager->hosts, &host_local, sizeof(host_local));
+		host = (zbx_ipmi_manager_host_t *)zbx_hashset_insert(&manager->hosts, &host_local, sizeof(host_local));
 
 		host->disable_until = 0;
 		host->poller = ipmi_manager_get_host_poller(manager);
@@ -972,6 +972,8 @@ ZBX_THREAD_ENTRY(ipmi_manager_thread, args)
 	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(program_type),
 			server_num, get_process_type_string(process_type), process_num);
 
+	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
+
 	if (FAIL == zbx_ipc_service_start(&ipmi_service, ZBX_IPC_SERVICE_IPMI, &error))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "cannot start IPMI service: %s", error);
@@ -989,9 +991,7 @@ ZBX_THREAD_ENTRY(ipmi_manager_thread, args)
 
 	zbx_setproctitle("%s #%d started", get_process_type_string(process_type), process_num);
 
-	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
-
-	for (;;)
+	while (ZBX_IS_RUNNING())
 	{
 		time_now = zbx_time();
 		now = time_now;
@@ -1062,10 +1062,13 @@ ZBX_THREAD_ENTRY(ipmi_manager_thread, args)
 		}
 	}
 
+	zbx_setproctitle("%s #%d [terminated]", get_process_type_string(process_type), process_num);
+
+	while (1)
+		zbx_sleep(SEC_PER_MIN);
+
 	zbx_ipc_service_close(&ipmi_service);
 	ipmi_manager_destroy(&ipmi_manager);
-
-	return 0;
 #undef STAT_INTERVAL
 }
 
